@@ -11,16 +11,27 @@ use Device::Microchip::Bootloader;
 my %opts;
 
 # Extract the power and area file options if they are passed.
-getopt( 'dfv', \%opts );
+getopt( 'dfvb', \%opts );
 
 #Pod::Help->help() if ( !defined $opts{d} && !defined $opts{h} );
 
 # Create the object
-my $loader = Device::Microchip::Bootloader->new(
-    firmware => $opts{f},
-    device   => $opts{d},
-    verbose  => $opts{v} || 0
-);
+my $loader;
+
+if ($defined %opts{b}) {
+    $loader = Device::Microchip::Bootloader->new(
+        firmware => $opts{f},
+        device   => $opts{d},
+        verbose  => $opts{v} || 0,
+        baudrate => %opts{b}
+    );
+} else {
+    $loader = Device::Microchip::Bootloader->new(
+        firmware => $opts{f},
+        device   => $opts{d},
+        verbose  => $opts{v} || 0,
+    );
+}
 
 # Connect to the target device over the specified connection
 $loader->connect_target();
@@ -64,7 +75,7 @@ ploader.pl - Bootloader for Microchip PIC devices
 
 =head1 VERSION
 
-version 0.5
+version 0.6
 
 =head1 DESCRIPTION
 
@@ -79,6 +90,9 @@ ploader.pl -d <device> -f <hexfile>
 Where C<device> is either a serial port or a TCP socket (format host:portnumber)
 and C<hexfile> is the Intel hex file to be loaded into the PIC.
 
+When using a serial port, the default baudrate used is 115200 bps. To override, pass
+the parameter 'b' with the required baudrate when invoking the script.
+
 Optionally, a parameter -v <verboselevel> can be passed to modify the verbosity
 of the Device::Microchip::Bootloader module. Defaults to '0', set to '3' for useful
 debugging.
